==> blobAndConquer-0.8-2.tar.gz: blobAndConquer-0.8/src/misc.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void drawWidgets();
extern void showMessageDialog(char *message, char *buttonLabel);
extern int showOKCancelDialog(char *message, int x, int y);
extern void loadWidgets(char *filename);
extern void loadGameLocaleData(char *filename, bool append);
extern List *loadProperties(char *filename, bool fromPak);
extern void setStatusIndicator();
extern void drawSlotItem(Entity *item, int x, int y);
extern GLColor getUnitHealthColor(Unit *unit);
extern GLColor getUnitShieldColor(Unit *unit);
extern void resetControlSlots(Unit *unit);
extern void addItemToList(ListView *listView, Entity *entity, bool showWeight);

extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern TextureManager *textureManager;
extern UIManager *uiManager;

==> blobAndConquer-0.93-2.tar.gz: blobAndConquer-0.93/src/misc.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void drawWidgets();
extern void showMessageDialog(const char *message, const char *buttonLabel);
extern int showOKCancelDialog(const char *message, int x, int y);
extern void loadWidgets(char *filename);
extern List *loadProperties(char *filename, bool fromPak);
extern void setStatusIndicator();
extern void drawSlotItem(Entity *item, int x, int y);
extern GLColor getUnitHealthColor(Unit *unit);
extern GLColor getUnitShieldColor(Unit *unit);
extern void resetControlSlots(Unit *unit);
extern void addItemToList(ListView *listView, Entity *entity, bool showWeight);

extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern TextureManager *textureManager;
extern UIManager *uiManager;
